"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const constants_1 = require("../utils/constants");
const fs_1 = require("./native/fs");
const util_1 = require("../utils/util");
const path_1 = __importDefault(require("path"));
class DataService {
    async add(url) {
        if (!(await this.isDataExist())) {
            await fs_1.mkdirPromise(path_1.default.dirname(constants_1.AH_DATA_PATH), {
                recursive: true,
            });
            await fs_1.writeFilePromise(constants_1.AH_DATA_PATH, JSON.stringify([
                {
                    id: 0,
                    lastHeartBeat: Date.now(),
                    url,
                },
            ]));
            return;
        }
        const data = await fs_1.readFilePromise(constants_1.AH_DATA_PATH);
        let apps = util_1.parseDataFromBuffer(data);
        const foundApp = apps.find((app) => app.url === url);
        if (!foundApp) {
            apps.push({
                id: apps.length,
                lastHeartBeat: Date.now(),
                url,
            });
            await fs_1.writeFilePromise(constants_1.AH_DATA_PATH, JSON.stringify(apps));
        }
    }
    async remove(id) {
        if (!(await this.isDataExist())) {
            return;
        }
        const data = await fs_1.readFilePromise(constants_1.AH_DATA_PATH);
        let apps = util_1.parseDataFromBuffer(data);
        apps = apps.filter((app) => app.id !== id);
        await fs_1.writeFilePromise(constants_1.AH_DATA_PATH, JSON.stringify(apps));
    }
    async get(id) {
        if (!(await this.isDataExist())) {
            return;
        }
        const data = await fs_1.readFilePromise(constants_1.AH_DATA_PATH);
        let apps = util_1.parseDataFromBuffer(data);
        const foundApp = apps.find((app) => app.id === id);
        return foundApp;
    }
    async getAll() {
        if (!(await this.isDataExist())) {
            return [];
        }
        const data = await fs_1.readFilePromise(constants_1.AH_DATA_PATH);
        let apps = util_1.parseDataFromBuffer(data);
        return apps;
    }
    async isDataExist() {
        return await fs_1.existsPromise(constants_1.AH_DATA_PATH);
    }
}
exports.default = new DataService();
